================
Optional plugins
================

.. toctree::
   :maxdepth: 2

   optional/avocado_ec2
   optional/glib
   optional/golang
   optional/remote_runners
   optional/results
   optional/robot
   optional/varianter_cit
   optional/varianter_pict
   optional/varianter_yaml_to_mux
   optional/yaml_loader
